.. image:: https://readthedocs.org/projects/sctop/badge/?version=latest
   :target: https://sctop.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://badge.fury.io/py/sctop.svg
   :target: https://badge.fury.io/py/sctop
   :alt: PyPI version

=========================================================================================
scTOP: Single-cell Type Order Parameters
=========================================================================================

A Python package for analyzing cell type using single-cell RNA-sequencing data. See our paper for more details: `Development <https://doi.org/10.1242/dev.201873>`_.

`Documentation available via Read the Docs <https://sctop.readthedocs.io/>`_ 

Please report bugs or request new features in the Github "Issues" tab. You can also contact Maria or Huan directly at ``mariay@bu.edu`` and ``hsouza@bu.edu``.

Installation
=============

To install using pip: ``pip install sctop``
To install from github: clone or download this repo and import the module from the ``sctop`` directory.

Dependencies
-------------
* NumPy
* Pandas
* SciPy
* scikit-learn
* Anndata
* tqdm
* numba
* matplotlib
* seaborn
* tables
* requests

Sources for reference databases
=================================
* `Mouse Cell Atlas <http://bis.zju.edu.cn/MCA/>`_
* `Herriges et al. <https://doi.org/10.1101/2022.07.26.501591>`
